@@ -25,6 +25,8 @@ diags_dict['[OI] 5577/6302'] = ('O1', 'L(5577)/L(6300)', 'RMS([E(6300), E(5577)]
 diags_dict['[OI] 5577/6300'] = ('O1', 'L(5577)/L(6300)', 'RMS([E(6300), E(5577)])')
 diags_dict['[OI] 5577/6300+'] = ('O1', 'L(5577)/(L(6300)+L(6364))', 'RMS([E(6300)*L(6300)/(L(6300)+L(6364)), E(6364)*L(6364)/(L(6300)+L(6364)), E(5577)])')
 diags_dict['[OII] 3726/3729'] = ('O2', 'L(3726)/L(3729)', 'RMS([E(3729), E(3726)])')
+diags_dict['[OII] 3727+/7325+c'] =  ('O2', '(B("3727A+"))/(B("7319A+")+B("7330A+"))',
+            'RMS([BE("7319A+")*B("7319A+")/(B("7319A+")+B("7330A+")), BE("7330A+")*B("7330A+")/(B("7319A+")+B("7330A+")), BE("3727A+")])')
 diags_dict['[OII] 3727+/7325+'] = ('O2', '(L(3726)+L(3729))/(B("7319A+")+B("7330A+"))',
               'RMS([E(3726)*L(3726)/(L(3726)+L(3729)), E(3729)*L(3729)/(L(3726)+L(3729)),BE("7319A+")*B("7319A+")/(B("7319A+")+B("7330A+")),BE("7330A+")*B("7330A+")/(B("7319A+")+B("7330A+"))])')
 #diags_dict['[OII] 3727+/7325+'] = ('O2', '(L(3726)+L(3729))/(B("7325A+"))', 'RMS([E(3726)*L(3726)/(L(3726)+L(3729)), E(3729)*L(3729)/(L(3726)+L(3729)),BE("7325A+")])')
@@ -160,7 +162,7 @@ class Diagnostics(object):
     It is also the class that plots the diagnostic Te-Ne diagrams.
 
     """    
-    def __init__(self, addAll=False, OmegaInterp='Cheb'):
+    def __init__(self, addAll=False, OmegaInterp='Cheb', NLevels=None):
         """
         Diagnostics constructor
         
@@ -180,6 +182,7 @@ class Diagnostics(object):
         # The dictionary containing the atoms used for the diagnostics        
         self.atomDict = {}
         self.OmegaInterp = OmegaInterp
+        self.NLevels = NLevels
         if addAll:
             self.addAll()
 
@@ -325,7 +328,7 @@ class Diagnostics(object):
                             'or an ion, or a wave range. label={0}, diag_tuple={1}, atom={2}, wave_range={3}'.format(label, diag_tuple, atom, wave_range),
                             calling=self.calling + '.addDiag')
         if atom not in self.atomDict and (type(label) is not list):
-            self.atomDict[atom] = pn.Atom(parseAtom(atom)[0], parseAtom(atom)[1])
+            self.atomDict[atom] = pn.Atom(parseAtom(atom)[0], parseAtom(atom)[1], NLevels=self.NLevels)
                
                
     def addAll(self):
@@ -368,7 +371,6 @@ class Diagnostics(object):
         if not isinstance(obs, pn.Observation):
             pn.log_.error('The argument must be an Observation object', calling=self.calling + 'addDiagsFromObs')
         old_level = pn.log_.level
-        pn.log_.level = 1
         def I(i, j):
             wave = atom.wave_Ang[i - 1, j - 1]
             corrIntens = obs.getLine(sym, spec, wave).corrIntens
@@ -388,19 +390,26 @@ class Diagnostics(object):
         for label in diags_dict:
             atom, diag_expression, error = diags_dict[label]
             sym, spec, rec = parseAtom2(atom)
+            if label == '[OII] 3727+/7325+c':
+                try:
+                    diag_value = eval(diag_expression)
+                except Exception as ex:
+                    pn.log_.level = old_level
+                    pn.log_.debug('Diag not valid {} {}'.format(label, diag_expression))
             try:
+                pn.log_.level = 1
                 diag_value = eval(diag_expression)
+                pn.log_.level = old_level
                 if atom not in self.atomDict:
                     if rec == 'r':
                         self.atomDict[atom] = pn.RecAtom(atom=sym+spec)
                     else:
-                        self.atomDict[atom] = pn.Atom(atom=atom)
+                        self.atomDict[atom] = pn.Atom(atom=atom, NLevels=self.NLevels)
                 self.addDiag(label)
             except Exception as ex:
-                pass
-                #print(diag_expression)
-        pn.log_.level = old_level
-    
+                pn.log_.level = old_level
+                pn.log_.debug('Diag not valid {} {}'.format(label, diag_expression))
+                
     
     def setAtoms(self, atom_dic):
         """
@@ -474,6 +483,7 @@ class Diagnostics(object):
         X = np.log10(emis_grids[list(emis_grids.keys())[0]].den2D)
         Y = emis_grids[list(emis_grids.keys())[0]].tem2D
         for label in self.diags:
+            self.log_.message('plotting {0}'.format(label), calling=self.calling)
             diag = self.diags[label]
             atom = diag[0]
             def I(i, j):
@@ -569,19 +579,26 @@ class Diagnostics(object):
                     style = style_dic[spec]
                     if tol_value > 0. and error_band:
                         levels = [(1 - tol_value) * diag_value, (1 + tol_value) * diag_value]
-                        CS = ax.contourf(X, Y, diag_map, levels=levels, alpha=alpha, colors=col)
+                        if levels[0] < levels[1]:
+                            #pn.log_.debug('{} levels {}'.format(label, levels), calling=self.calling)
+                            CS = ax.contourf(X, Y, diag_map, levels=levels, alpha=alpha, colors=col)
                     CS = ax.contour(X, Y, diag_map, levels=[diag_value], colors=col, linestyles=style)
-                    ax.set_xlabel(r'log(n$_{\rm e}$) [cm$^{-3}$]')
-                    ax.set_ylabel(r'T$_{\rm e}$ [K]')
-                    if len(diag) >= 4:
-                        fmt = diag[3]
-                    else:
-                        fmt = '[{0}{1}]'.format(sym, int_to_roman(int(spec)))
-                    ax.clabel(CS, inline=True, fmt=fmt, fontsize=15, colors=col)
-                    if type(diag_value) is np.ndarray:
-                        diag_value = diag_value[0]
-                    self.log_.message('plotting {0}: {1} = {2:.2} with error of {3:.2} %'.format(fmt, label, diag_value, tol_value * 100),
-                                      calling=self.calling)
+                    try:
+                        ax.set_xlabel(r'log(n$_{\rm e}$) [cm$^{-3}$]')
+                        ax.set_ylabel(r'T$_{\rm e}$ [K]')
+                        if len(diag) >= 4:
+                            fmt = diag[3]
+                        else:
+                            fmt = '[{0}{1}]'.format(sym, int_to_roman(int(spec)))
+                        ax.clabel(CS, inline=True, fmt=fmt, fontsize=15, colors=col)
+                        if type(diag_value) is np.ndarray:
+                            diag_value = diag_value[0]
+                        self.log_.message('plotted {0}: {1} = {2:.2} with error of {3:.2} %'.format(fmt, label, diag_value, tol_value * 100),
+                                          calling=self.calling)
+                    except:
+                        self.log_.message('NOT plotted {0} {1}'.format(fmt, label),
+                                          calling=self.calling)
+                        
         
         
     def getCrossTemDen(self, diag_tem, diag_den, value_tem=None, value_den=None, obs=None, i_obs=None,
@@ -624,14 +641,14 @@ class Diagnostics(object):
         atom_tem = self.diags[diag_tem][0]
         elem_tem, spec_tem = parseAtom(atom_tem)
         if atom_tem not in self.atomDict:
-            self.atomDict[atom_tem] = pn.Atom(elem_tem, spec_tem, self.OmegaInterp)
+            self.atomDict[atom_tem] = pn.Atom(elem_tem, spec_tem, self.OmegaInterp, NLevels=self.NLevels)
         atom_tem = self.atomDict[atom_tem]
         if diag_den not in self.diags:
             self.addDiag(diag_den)
         atom_den = self.diags[diag_den][0]
         elem_den, spec_den = parseAtom(self.diags[diag_den][0])
         if (atom_den) not in self.atomDict:
-            self.atomDict[atom_den] = pn.Atom(elem_den, spec_den, self.OmegaInterp)
+            self.atomDict[atom_den] = pn.Atom(elem_den, spec_den, self.OmegaInterp, NLevels=self.NLevels)
         atom_den = self.atomDict[atom_den]
         eval_tem = self.diags[diag_tem][1]
         eval_den = self.diags[diag_den][1]
