@@ -2,6 +2,7 @@ import numpy as np
 import pyneb as pn
 from pyneb.utils.init import ELEM_LIST, SPEC_LIST
 from pyneb.utils.misc import parseAtom
+import random
 
 class ICF(object):
 
@@ -104,6 +105,16 @@ class ICF(object):
                                        'icf': '1',
                                        'type': 'All',
                                        'comment': 'just summing visible ions'},
+                         'direct_Ar.234':{'elem': 'Ar',
+                                       'atom': 'abun["Ar2"] + abun["Ar3"] + abun["Ar4"]',
+                                       'icf': '1',
+                                       'type': 'All',
+                                       'comment': 'just summing visible ions'},
+                         'direct_Ar.345':{'elem': 'Ar',
+                                       'atom': 'abun["Ar3"] + abun["Ar4"] + abun["Ar5"]',
+                                       'icf': '1',
+                                       'type': 'All',
+                                       'comment': 'just summing visible ions'},
                          'direct_Cl.23':{'elem': 'Cl',
                                        'atom': 'abun["Cl2"] + abun["Cl3"]',
                                        'icf': '1',
@@ -301,8 +312,8 @@ class ICF(object):
 #
 # Unsure about this icf. I don't know if eq. 28 can be mixed with eq. 6. In any case, I explicitly set out the conditions of eq. 6 in the comment.
                          'KB94_A28.6':{'elem': 'Ne',
-                                     'atom': 'abun["Ne3"]',
-                                     'icf': 'elem_abun["KB94_A6"]  / abun["O3"]',
+                                       'atom': 'abun["Ne3"]',
+                                       'icf': 'elem_abun["KB94_A6"]  / abun["O3"]',
                                       'type': 'PNe',
 # Wrong comment. Corrected 19 Dec 2014
 #                                      'comment': 'Based on a grid of photoionization models. Valid if N4 or N5 not seen'},
@@ -521,72 +532,107 @@ class ICF(object):
                                        'atom':'abun["O2"] + abun["O3"]', 
                                        'icf': '10**((0.08 * abun["He3"] / (abun["He2"] + abun["He3"]) + 0.006 * (abun["He3"] / (abun["He2"] + abun["He3"]))**2) / (0.34 - 0.27 * abun["He3"] / (abun["He2"] + abun["He3"])))',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.03 + 0.5 * abun["He3"] / (abun["He2"] + abun["He3"]) - 0.2 * (abun["He3"] / (abun["He2"] + abun["He3"]))**2',
+                                       'up_error': '0.03 + 0.5 * abun["He3"] / (abun["He2"] + abun["He3"]) - 0.2 * (abun["He3"] / (abun["He2"] + abun["He3"]))**2'},
                          'DIMS14_14': {'elem': 'N',
                                        'atom':'abun["N2"]', 
                                        'icf': '10**(-0.16 * abun["O3"] / (abun["O2"] + abun["O3"]) * (1.0 + np.log10(abun["He3"] / (abun["He2"] + abun["He3"])))) * elem_abun["DIMS14_12"] / abun["O2"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.32 * abun["O3"] / (abun["O2"] + abun["O3"])',
+                                       'up_error': '0.50 * abun["O3"] / (abun["O2"] + abun["O3"])'},
                          'DIMS14_14b': {'elem': 'N',
                                        'atom':'abun["N2"]', 
                                        'icf': '10**(0.64 * abun["O3"] / (abun["O2"] + abun["O3"])) * elem_abun["DIMS14_12"] / abun["O2"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.32 * abun["O3"] / (abun["O2"] + abun["O3"])',
+                                       'up_error': '0.50 * abun["O3"] / (abun["O2"] + abun["O3"])'},
                          'DIMS14_17a': {'elem': 'Ne',
                                        'atom':'abun["Ne3"]', 
                                        'icf': '(abun["O3"] / (abun["O2"] + abun["O3"]) + (0.014 / (abun["He3"] / (abun["He2"] + abun["He3"])) + 2 * (abun["He3"] / (abun["He2"] + abun["He3"]))**2.7)**3 * (0.7 + 0.2 * abun["O3"] / (abun["O2"] + abun["O3"]) - 0.8 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2)) * elem_abun["DIMS14_12"] / abun["O3"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.17',
+                                       'up_error': '0.12'},
                          'DIMS14_17b': {'elem': 'Ne',
                                        'atom':'abun["Ne3"]', 
                                        'icf': '(abun["O3"] / (abun["O2"] + abun["O3"]) + (0.014 / (0.01) + 2 * (0.01)**2.7)**3 * (0.7 + 0.2 * abun["O3"] / (abun["O2"] + abun["O3"]) - 0.8 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2)) * elem_abun["DIMS14_12"] / abun["O3"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.17',
+                                       'up_error': '0.12'},
                          'DIMS14_17c': {'elem': 'Ne',
                                        'atom':'abun["Ne3"]', 
                                        'icf': '(abun["O3"] / (abun["O2"] + abun["O3"]) + (0.014 / (0.015) + 2 * (0.015)**2.7)**3 * (0.7 + 0.2 * abun["O3"] / (abun["O2"] + abun["O3"]) - 0.8 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2)) * elem_abun["DIMS14_12"] / abun["O3"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.17',
+                                       'up_error': '0.12'},
+                         'DIMS14_20': {'elem': 'Ne',
+                                       'atom':'abun["Ne3"]+abun["Ne5"]', 
+                                       'icf': '(1.31+12.68*(abun["He3"]/(abun["He2"]+abun["He3"]))**2.57)**0.27',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.20',
+                                       'up_error': '0.17'},
                          'DIMS14_23': {'elem': 'S',
                                        'atom':'abun["S2"]', 
                                        'icf': '(10**(0.31 - 0.52 * abun["He3"] / (abun["He2"] + abun["He3"]))) * elem_abun["DIMS14_12"] / abun["O2"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.38',
+                                       'up_error': '0.41'},
                          'DIMS14_26': {'elem': 'S',
                                        'atom':'abun["S2"] + abun["S3"]', 
                                        'icf': '(10**((-0.02 - 0.03*abun["O3"] / (abun["O2"] + abun["O3"]) - 2.31*(abun["O3"] / (abun["O2"] + abun["O3"]))**2 + 2.19 * (abun["O3"] / (abun["O2"] + abun["O3"]))**3) / (0.69 + 2.09 * abun["O3"] / (abun["O2"] + abun["O3"]) - 2.69 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2))) * elem_abun["DIMS14_12"] / abun["O2"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.20',
+                                       'up_error': '0.12'},
                          'DIMS14_29': {'elem': 'Cl',
                                        'atom':'abun["Cl3"]', 
                                        'icf': '((4.162 - 4.1622*(abun["O3"] / (abun["O2"] + abun["O3"]))**0.21)**.75) * elem_abun["DIMS14_12"] / abun["O2"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.27',
+                                       'up_error': '0.15'},
                          'DIMS14_29b': {'elem': 'Cl',
                                        'atom':'abun["Cl2"] + abun["Cl3"]', 
                                        'icf': '(1.) * elem_abun["DIMS14_12"] / abun["O2"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.13',
+                                       'up_error': '0.0'},
                          'DIMS14_32': {'elem': 'Cl',
                                        'atom':'abun["Cl2"] + abun["Cl3"] + abun["Cl4"]', 
                                        'icf': '0.98 + (0.56 - 0.57 * abun["He3"] / (abun["He2"] + abun["He3"]))**7.64',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.30',
+                                       'up_error': '0.33'},
                          'DIMS14_35': {'elem': 'Ar',
                                        'atom':'abun["Ar3"]', 
                                        'icf': '(10**(0.05 / (0.06 + abun["O3"] / (abun["O2"] + abun["O3"])) - 0.07)) * elem_abun["DIMS14_12"] / (abun["O2"] + abun["O3"])',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.70',
+                                       'up_error': '0.60'},
                          'DIMS14_36': {'elem': 'Ar',
                                        'atom':'abun["Ar3"]', 
                                        'icf': '(10**((0.03  * abun["O3"] / (abun["O2"] + abun["O3"])) / (0.4 - 0.3 * abun["O3"] / (abun["O2"] + abun["O3"])) - 0.05)) * elem_abun["DIMS14_12"] / (abun["O2"] + abun["O3"])',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.70',
+                                       'up_error': '0.60'},
                          'DIMS14_39': {'elem': 'C',
                                        'atom':'abun["C3"]', 
                                        'icf': '(0.05 + 2.21 * abun["O3"] / (abun["O2"] + abun["O3"]) - 2.77 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2 + 1.74 * (abun["O3"] / (abun["O2"] + abun["O3"]))**3) * elem_abun["DIMS14_12"] / abun["O3"]',
                                        'type': 'PNe',
-                                       'comment': 'Based on photoionization models'},
+                                       'comment': 'Based on photoionization models',
+                                       'low_error': '0.19',
+                                       'up_error': '(0.4 - 1.06 * abun["O3"] / (abun["O2"] + abun["O3"]) + 0.65 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2 + 0.27 * (abun["O3"] / (abun["O2"] + abun["O3"]))**3) '},
 # To be completed
 #                         'Sal07_Kr1': {'elem': 'Kr',
 #                                       'atom':'abun["Kr3"] + abun["Kr4"]', 
@@ -777,7 +823,7 @@ class ICF(object):
 
         """
         if label in self.all_icfs:
-            pn.log_.warn('{0} is already an entry of the ICF label dictionary', calling=self.calling)
+            pn.log_.warn('{0} is already an entry of the ICF label dictionary'.format(label), calling=self.calling)
             return None
         else:
             self.all_icfs[label] = {'elem': elem,
@@ -819,14 +865,14 @@ class ICF(object):
         """        
         for item in self.all_icfs:
             if (label in item):
-                print '------------------------------------------------------------------------'
-                if ('l' in filter): print 'Label:', item
-                if ('e' in filter): print 'Element:', self.all_icfs[item]['elem']
-                if ('r' in filter): print 'Required ions:', self._getAtomExp(item)
-                if ('i' in filter): print 'ICF expression:', self._getIcfExp(item)
-                if ('o' in filter): print 'Object class:', self.all_icfs[item]['type']
-                if ('c' in filter): print 'Comments:', self.all_icfs[item]['comment']
-                if ('s' in filter): print 'Source:', self.getReference(item)
+                print('------------------------------------------------------------------------')
+                if ('l' in filter): print('Label:', item)
+                if ('e' in filter): print('Element:', self.all_icfs[item]['elem'])
+                if ('r' in filter): print('Required ions:', self._getAtomExp(item))
+                if ('i' in filter): print('ICF expression:', self._getIcfExp(item))
+                if ('o' in filter): print('Object class:', self.all_icfs[item]['type'])
+                if ('c' in filter): print('Comments:', self.all_icfs[item]['comment'])
+                if ('s' in filter): print('Source:', self.getReference(item))
    
     
     def getReference(self, label): 
@@ -904,7 +950,8 @@ class ICF(object):
         """
         return self.all_icfs[label]['comment']
 
-    def getElemAbundance(self, atom_abun, icf_list=[], icf_family=None, absentIon=np.nan, use_coll=True):
+    def getElemAbundance(self, atom_abun, icf_list=[], icf_family=None, absentIon=np.nan, use_coll=True,
+                         use_MC=False):
         """
         Compute elemental abundances from ionic abundances. The complete iventory is printed through pn.ICF().printAllICFs().
         See the ICF class for more details.
@@ -915,7 +962,9 @@ class ICF(object):
            - icf_list     a list of selected ICFs (default: all)
            - icf_family   a string common to all the icf one want to use, e.g. "DIMS14"
            - use_coll     In case both collision lines and recombination lines abundances exists:
-                           if True (default), use collision line ionic abundance, if false use recombination ones  
+                           if True (default), use collision line ionic abundance, if false use recombination ones
+           - use_MC       If True and if the ICF definition includes error informations, the ICF will be multiplied
+                           by some factor taking into account the error.
         Usage:
             atom_abun = {'O2': 0.001, 'O3': 0.002, 'Ne3': 1.2e-5}
             getElemAbundance(atom_abun)
@@ -933,6 +982,7 @@ class ICF(object):
         atom_list.extend(['He2', 'He3', 'He1r', 'He2r', 'O2r'])
     
         # Initialize the ionic abundances so that the code does not crash when a specific abundance is invoked
+        # TODO : Check that the same ion is not present as collisional and recombination !!
         abun = {}
         for atom in atom_list:
             # Set those abundances which are different from 0. These determine which ICFs can be computed        
@@ -967,19 +1017,57 @@ class ICF(object):
                 try:
                     atom_value = eval(atom)
                 except:
-                    pass
+                    pn.log_.warn('Unable to eval {}'.format(atom))
                 if self.all_icfs[icf_label]['elem'] is not None:
-                    elem = self.all_icfs[icf_label]['elem']
+                    pn.log_.debug('Doing {}'.format(icf_label), calling='ICF')
+                    this_icf = self.all_icfs[icf_label]
+                    elem = this_icf['elem']
                     try:
-                        icf_value = eval(self.all_icfs[icf_label]['icf'])
+                        icf_value = eval(this_icf['icf'])
                         self.icf_value[icf_label] = icf_value
+                        if use_MC and 'low_error' in this_icf:
+                            try:
+                                low_error = eval(this_icf['low_error'])
+                            except:
+                                pn.log_.warn('low error {0} cannot be evaluated for {1}'.format(this_icf['low_error'], icf_label))
+                            try:
+                                up_error = eval(this_icf['up_error'])
+                            except:
+                                pn.log_.warn('up error {0} cannot be evaluated for {1}'.format(this_icf['up_error'], icf_label))
+                            try:
+                                if np.size(low_error) == 1:
+                                    D_icf_MC = np.random.uniform(-low_error, up_error, np.size(atom_value))
+                                else:
+                                    D_icf_MC = np.random.uniform(-low_error, up_error)
+                                D_icf_MC[0] = 0.0
+                            except:
+                                pn.log_.warn('MC not working for ICF {}'.format(this_icf['icf']), calling=self.calling)
+#                             print '--------IN---------'
+#                             print this_icf['icf']
+#                             print this_icf['low_error']
+#                             print 'low_error'
+#                             print low_error
+#                             print this_icf['up_error']
+#                             print 'up_error'
+#                             print up_error
+#                             if icf_label == 'DIMS14_36':
+#                                 print 'icf_MC for {}'.format(icf_label)
+#                                 print Dicf_MC
+#                                 print 'icf_value'                            
+#                                 print icf_value
+                            icf_value = icf_value + D_icf_MC
+                            pn.log_.message('Using MC for ICF {}'.format(icf_label))
+#                             print 'icf_value2'                            
+#                             print icf_value
+#                             print '---------OUT---------'
                         elem_abun[icf_label] = atom_value * icf_value
                     except:
                         do_one_more_pass = True
                         if i_pass == self._max_pass:
-                            pn.log_.warn('{0} cannot be evaluated'.format(self.all_icfs[icf_label]['icf']),
+                            pn.log_.warn('{0} cannot be evaluated for {1}'.format(this_icf['icf'], icf_label),
                                          calling=self.calling)
-
+                else:
+                    pn.log_.debug('{} not present'.format(icf_label), calling='ICF')
         self.elem_abun = elem_abun
         return self.elem_abun
 #            elem_abun[icf.all_icfs[icf_ref]['elem']] = np.log10(elem_abun_dic[icf_ref])+12
@@ -1032,22 +1120,22 @@ class ICF(object):
         label2 = 'TPP77_14'
         label3 = 'KH01_4b'
         label4 = 'PHCD07_13'
-        print 'All the available ICFs, listed by element:'   
-        print self.getAvailableICFs()
-        print '\nAll the available ICFs, with some detail:'   
-        print self.printAllICFs()
-        print '\nAll the available ICFs for S and Ne:'   
-        print self.getAvailableICFs(['S', 'Ne'])
-        print '\nAnalytical expression for ' + label1 + ':'
-        print self.getExpression(label1)
-        print '\nBibliographic reference for ' + label2 + ':'
-        print self.getReference(label2)
-        print '\nURL for ' + label3 + ':'
-        print self.getURL(label3)
-        print '\nType of object to which ' + label4 + ' can be applied:'
-        print self.getType(label4)
-        print '\nAdditional details of ' + label4 + ':'
-        print self.getComment(label4) 
+        print('All the available ICFs, listed by element:')
+        print(self.getAvailableICFs())
+        print('\nAll the available ICFs, with some detail:')
+        print(self.printAllICFs())
+        print('\nAll the available ICFs for S and Ne:' )  
+        print(self.getAvailableICFs(['S', 'Ne']))
+        print('\nAnalytical expression for ' + label1 + ':')
+        print(self.getExpression(label1))
+        print('\nBibliographic reference for ' + label2 + ':')
+        print(self.getReference(label2))
+        print('\nURL for ' + label3 + ':')
+        print(self.getURL(label3))
+        print('\nType of object to which ' + label4 + ' can be applied:')
+        print(self.getType(label4))
+        print('\nAdditional details of ' + label4 + ':')
+        print(self.getComment(label4) )
 
         atom_abun = {}
         atom_abun['O2'] = 0.001
