@@ -93,6 +93,7 @@ LINE_LABEL_LIST['N3'] = ['1749A', '1754A', '1747A', '1752A', '1744A', '1750A', '
                          '2288A', '2280A', '2283A', '2287A', '763A', '764A', '1356A', '1357A', '3334A', 
                          '3335A', '57.4m', '167.5m', '71.0m', '123.3m', '1492.1m']
 LINE_LABEL_LIST['N4'] = ['1488A', '1487A', '1483A', '765A', '1575A', '1576A', '1580A', '158.4m', '48.3m', '69.4m']
+LINE_LABEL_LIST['N5'] = ['1239A', '1243A']
 LINE_LABEL_LIST['Na3'] = ['7.3m']
 LINE_LABEL_LIST['Na4'] = ['3242A', '3362A', '3416A', '1504A', '1529A', '1540A', '2804A', '9.0m', '6.34m', '21.3m']
 LINE_LABEL_LIST['Na6'] = ['2816A', '2872A', '2972A', '1343A', '1356A', '1378A', '2569A', '14.39m', '5.4m', '8.6m']
@@ -134,6 +135,7 @@ LINE_LABEL_LIST['Se4'] = ['2.28m']
 LINE_LABEL_LIST['Si2'] = ['2335A', '2351A', '2329A', '2345A', '2320A', '1808A', '1817A', '8007A', '8077A', '8193A', 
                           '7997A', '8067A', '8183A', '34.8m', '92.3m', '35.2m', '57.1m', '631.5m']
 LINE_LABEL_LIST['Si3'] = ['1897A', '1892A', '1883A', '1206A', '3315A', '3329A', '3359A', '77.7m', '25.7m', '38.2m']
+LINE_LABEL_LIST['Si4'] = ['1394A', '1403A']
 LINE_LABEL_LIST['Xe3'] = ['5847A', '2769A', '3574A', '3800A', '5261A', '1.23m', '1.02m', '6.0m', '1.11m', '1.37m']
 LINE_LABEL_LIST['Xe4'] = ['7535A', '5709A', '3566A', '6769A', '9498A', '2804A', '4467A', '5511A', '2.36m', '1.31m']
 LINE_LABEL_LIST['Xe6'] = ['6409A']
@@ -216,13 +218,16 @@ BLEND_LIST['N1_3466A+'] = 'I(4,1)+I(5,1)'
 BLEND_LIST['N1_1.0m+'] = 'I(4,2)+I(4,3)+I(5,2)+I(5,3)'
 BLEND_LIST['N3_1750A+'] = 'I(3,1)+I(3,2)+I(4,1)+I(4,2)+I(5,1)+I(5,2)'
 BLEND_LIST['N4_1485A+'] = 'I(4,1)+I(3,1)'
+BLEND_LIST['N5_1240A+'] = 'I(2,1)+I(3,1)'
 BLEND_LIST['O2_3727A+'] = 'L(3726)+L(3729)'
 BLEND_LIST['O2_1075A+'] = 'I(6,2)+I(6,3)'
+BLEND_LIST['O2_3727A+'] = 'I(2,1)+I(3,1)'
 BLEND_LIST['O2_7330A+'] = 'I(4,3)+I(5,3)'
 BLEND_LIST['O2_7319A+'] = 'I(4,2)+I(5,2)'
 BLEND_LIST['O2_7325A+'] = 'I(4,2)+I(5,2)+I(4,3)+I(5,3)'
 BLEND_LIST['O3_1664A+'] = 'L(1660)+L(1666)'
-BLEND_LIST['O4_1400A+'] = 'I(3,1)+I(3,2)+I(4,1)+I(4,2)+I(5,1)+I(5,2)'
+BLEND_LIST['O4_1401A+'] = 'I(3,1)+I(3,2)+I(4,1)+I(4,2)+I(5,1)+I(5,2)'
+BLEND_LIST['O4_1400A+'] = 'I(3,1)+I(4,1)+I(5,2)'
 BLEND_LIST['N3_1751A+'] = 'I(3,1)+I(3,2)+I(4,1)+I(4,2)+I(5,1)+I(5,2)'
 BLEND_LIST['Ne4_4726A+'] = 'L(4725)+L(4727)'
 BLEND_LIST['Ne4_2423A+'] = 'I(2,1)+I(3,1)'
