@@ -2,7 +2,7 @@ import os
 import pyneb as pn
 import numpy as np
 import re
-from .misc import execution_path, parseAtom, roman_to_int, multi_split, int_to_roman, strExtract, bs
+from .misc import execution_path, parseAtom, roman_to_int, multi_split, int_to_roman, strExtract
 from .init import ELEM_LIST, SPEC_LIST
 from .physics import _predefinedDataFileDict
 
@@ -231,7 +231,7 @@ class _ManageAtomicData(object):
         for dir in self._DataFilePaths:
             files = os.listdir(dir)
             for file in files:
-                if (('.fits' in file) or ('.hdf5' in file) or ('.dat' in file) ) and (atom_str in file):
+                if (('.fits' in file) or ('.func' in file) or ('.hdf5' in file) or ('.dat' in file) ) and (atom_str in file):
                     for dt in data_types:
                         if dt in file:
                             file_list.append(file)
@@ -494,7 +494,7 @@ You may mean one of these files: {1}""".format(data_file, av_data),
                         elif pn.config.Chianti_version_main == '8':
                             coll_file = '{0}/{1}/{2}/{2}.scups'.format(self.Chianti_path, elem, atom)
                         else:
-                            pn.config.error('Unknown version of Chianti {}'.format(pn.config.Chianti_version))
+                            pn.log_.error('Unknown version of Chianti {}'.format(pn.config.Chianti_version))
                         atom_file = '{0}/{1}/{2}/{2}.wgfa'.format(self.Chianti_path, elem, atom)
                         if os.path.exists(coll_file): 
                             self.ChiantiIONS['coll'].append(atom)
@@ -525,7 +525,8 @@ You may mean one of these files: {1}""".format(data_file, av_data),
     
     def read_gsconf(self):
         try:
-            gsconf = np.genfromtxt(execution_path('../atomic_data/levels/gsconfs.dat'), names=['atom', 'gsconf'], dtype=None)
+            gsconf = np.genfromtxt(execution_path('../atomic_data/levels/gsconfs.dat'), 
+                                   names=['atom', 'gsconf'], dtype='U5, U5')
             self.gsconf = {gs['atom']:gs['gsconf'] for gs in gsconf}
         except:
             self.gsconf = {}
@@ -567,15 +568,16 @@ For any moderately or highly excited line.
 
 def extract_flt(str_):
     """
+    Input is a bytes (py3) or a string (py2)
     Return the first float in str_, removing the no digit (and no dot) leading part of it.
     Ex:
-    extract_flt('123.00?') -> 123.00
+    extract_flt('(123.00?') -> 123.00
     """
     res = ''
     if len(str_) > 0:
-        if str_[0] in('(', '['):
+        if str_.decode()[0] in ('(', '['):
             str_ = str_[1:]
-    for l in bs(str_):
+    for l in str_.decode():
         if l.isdigit() or l == '.':
             res += l
         else:
@@ -585,14 +587,13 @@ def extract_flt(str_):
     else:
         return float(res)
 
-
 def readNIST(NISTfile,NLevels=None):
     """
     The NIST levels file must be obtained from this page:
         http://physics.nist.gov/PhysRefData/ASD/levels_form.html
     with the following options:
         Level Units: cm-1
-        Format output: ASCIIda
+        Format output: ASCII
         Display output: in its entirely
         Energy ordered
         Level Information: Principal configuration, Principal term, Level, J
@@ -600,40 +601,39 @@ def readNIST(NISTfile,NLevels=None):
     """
     data = np.genfromtxt(NISTfile, comments = '-', 
                     delimiter = '|', names = 'conf, term, J, energy, ref', 
-                    dtype=('a23', 'a9', 'a4', 'float', 'a10'), autostrip=True,
-                    converters = {'energy':extract_flt, 'J':bs, 'conf':bs, 'term': bs, 'ref':bs})
-    mask = data['J'] != bs('')
+                    dtype=('U23', 'U9', 'U4', 'float', 'U10'), autostrip=True,
+                    converters = {'energy':extract_flt})
+    mask = data['J'] != ''
     data = data[mask]
-    previous_ref = bs('')
-    previous_conf = bs('')
-    previous_term = bs('')
+    previous_ref = ''
+    previous_conf = ''
+    previous_term = ''
     for d in data:
-        if d['conf'] == bs(''):
+        if d['conf'] == '':
             d['conf'] = previous_conf
         else:
             previous_conf = d['conf']
-        if d['term'] == bs(''):
+        if d['term'] == '':
             d['term'] = previous_term
         else:
             previous_term = d['term']
-        if d['ref'] == bs(''):
+        if d['ref'] == '':
             d['ref'] = previous_ref
         else:
             previous_ref = d['ref']
             
-        if bs('?') in d['J']:
-            d['J'] = bs(d['J']).split('?')[0]
-        if d['J'] == bs(''):
+        if '?' in d['J']:
+            d['J'] = d['J'].split('?')[0]
+        if d['J'] == '':
             d['J'] = 0.
-        elif bs('/') in d['J']:
-            d['J'] = '{0:.1f}'.format(float(bs(d['J']).split('/')[0]) / float(bs(d['J']).split('/')[1]))
-        elif bs(',') in d['J']:
-            d['J'] = '{0:.1f}'.format(float(bs(d['J']).split(',')[0]))
+        elif '/' in d['J']:
+            d['J'] = '{0:.1f}'.format(float(d['J'].split('/')[0]) / float(d['J'].split('/')[1]))
+        elif ',' in d['J']:
+            d['J'] = '{0:.1f}'.format(float(d['J'].split(',')[0]))
         else:
-            d['J'] = '{0:.1f}'.format(float(bs(d['J'])))
-           
+            d['J'] = '{0:.1f}'.format(float(d['J']))
     data = data[data['energy'].argsort()]
-    data = data.astype([('conf', 'a23'), ('term', 'a9'), ('J', 'float'), ('energy', 'float'), ('ref', 'a10')])
+    data = data.astype([('conf', 'U23'), ('term', 'U9'), ('J', 'float'), ('energy', 'float'), ('ref', 'U10')])
     if NLevels is not None:
         data = data[0:NLevels]
     return data
