@@ -22,6 +22,7 @@ class CST(object):
 
 Z = {}
 Z["H"] = 1
+Z['D'] = 1
 Z["He"] = 2
 #Z["3He"] = 2
 Z["Li"] = 3
@@ -259,6 +260,13 @@ IP["Hs"] = [7.6, 18.2, 29.3, 37.7, 51.2, 64.0, 78.0, 92.0, 160.0, 173.9, 206.1,
 IP["Mt"] = [50.0, 94.0, 109.0, 187.0, 202.0, 235.9, 257.0, 289.0, 318.0, 346.0, 386.0, 406.0, 445.0, 1035.0, 1072.0, 1112.0, 1154.0, 1195.0, 1234.0, 1311.0, 1352.0, 1397.0, 1439.0, 4464.0, 4551.0, 4640.0, 4740.0, 4830.0, 4920.0, 5160.0, 5250.0, 5360.0, 5450.0, 5840.0, 5930.0, 6030.0, 6130.0, 7040.0, 7150.0, 7440.0, 7550.0, 11460.0, 11660.0, 11870.0, 12100.0, 12320.0, 12530.0, 13200.0, 13400.0, 13700.0, 13900.0, 14500.0, 14700.0, 14900.0, 15100.0, 17900.0, 18200.0, 18700.0, 18900.0, 36700.0, 37200.0, 37800.0, 38300.0, 48500.0, 49400.0, 50300.0, 199606.0]
 IP["Ds"] = [65.0, 112.9, 128.0, 216.0, 231.0, 266.0, 288.0, 322.0, 352.0, 380.0, 422.0, 442.0, 483.0, 1087.0, 1125.0, 1165.0, 1208.0, 1250.0, 1290.0, 1369.0, 1412.0, 1457.0, 1500.0, 4590.0, 4680.0, 4770.0, 4870.0, 4960.0, 5060.0, 5300.0, 5400.0, 5500.0, 5600.0, 5990.0, 6080.0, 6190.0, 6280.0, 7230.0, 7350.0, 7640.0, 7750.0, 11730.0, 11930.0, 12140.0, 12380.0, 12600.0, 12810.0, 13500.0, 13700.0, 14000.0, 14200.0, 14800.0, 15000.0, 15300.0, 15500.0, 18400.0, 18600.0, 19100.0, 19400.0, 37400.0, 37900.0, 38500.0, 39100.0, 49800.0, 50700.0, 51600.0, 204400.0]
 
+IP_tmp = IP.copy()
+
+for elem in IP_tmp:
+    IP[elem+'1'] = 0.0
+    for ion, ip in enumerate(IP[elem]):
+        IP['{}{}'.format(elem,ion+2)] = ip
+
 IP['H2'] = 13.59844
 IP['He1'] = 0.0
 IP['He2'] = 24.58741
@@ -267,92 +275,10 @@ IP['H1r'] = 13.59844
 IP['He1r'] = 24.58741
 IP['He2r'] = 54.41778
 
-IP['C1'] = 0.0
-IP['C2'] = 11.26
-IP['C3'] = 24.38
-IP['C4'] = 47.89
-IP['C5'] = 64.49
-IP['C6'] = 392.087
-IP['C7'] = 489.99334
-IP['N1'] = 0.0
-IP['N2'] = 14.53
-IP['N3'] = 29.60
-IP['N4'] = 47.45
-IP['N5'] = 77.47
-IP['O1'] = 0.0
-IP['O2'] = 13.62
-IP['O3'] = 35.12
-IP['O4'] = 54.94
-IP['S1'] = 0.0
-IP['S2'] = 10.36
-IP['S3'] = 23.34
-IP['S4'] = 34.79
-IP['S5'] = 47.22
-IP['Ne1'] = 0.0
-IP['Ne2'] = 21.56
-IP['Ne3'] = 40.96
-IP['Ne4'] = 63.45
-IP['Ne5'] = 97.12
-IP['Ne6'] = 126.21
-IP['Cl1'] = 0.0
-IP['Cl2'] = 12.97
-IP['Cl3'] = 23.81
-IP['Cl4'] = 39.61
-IP['Ar1'] = 0.0
-IP['Ar2'] = 15.76
-IP['Ar3'] = 27.63
-IP['Ar4'] = 40.74
-IP['Ar5'] = 59.81
-IP['Ba1'] = 0.00
-IP['Ba2'] = 5.21
-IP['Ba3'] = 10.003826
-IP['Ba4'] = 35.84
-IP['Xe1'] = 0.00
-IP['Xe3'] = 20.98
-IP['Xe4'] = 31.05
-IP['Xe5'] = 42.20
-IP['Xe6'] = 54.1
-IP['Mg1'] = 0.00
-IP['Mg2'] = 7.65
-IP['Mg3'] = 15.03
-IP['Mg4'] = 80.14
-IP['Mg5'] = 109.26
-IP['Fe1'] = 0.0
-IP['Fe2'] = 7.90 
-IP['Fe3'] = 16.188
-IP['Fe4'] = 30.652
-IP['Fe5'] = 54.8
-IP['Fe6'] = 75.0
-IP['Fe7'] = 98.99
-IP['Ni1'] = 0.
-IP['Ni2'] = 7.639877
-IP['Ni3'] = 18.168837
-IP['Ni4'] = 35.187
-IP['Kr1'] = 0.0
-IP['Kr2'] = 13.9996
-IP['Kr3'] = 24.35984
-IP['Kr4'] = 35.67
-IP['Kr5'] = 50.85
-IP['Na1'] = 0.0
-IP['Na2'] = 5.1390767
-IP['Na3'] = 47.28636
-IP['Na4'] = 71.6200
-IP['Na5'] = 98.936
-IP['Rb1'] = 0.0
-IP['Rb2'] = 4.177128
-IP['Rb3'] = 27.28954
-IP['Rb4'] = 39.2472
-IP['Rb5'] = 52.20
-IP['K1'] = 0.0
-IP['K2'] = 4.34066354
-IP['K3'] = 31.62500
-IP['K4'] = 45.8031
-IP['K5'] = 60.917
-IP['K6'] = 82.66
-
 sym2name = {
             'H': 'hydrogen',
             '3He': 'helium',
+            'D': 'deuterium',
             'He': 'helium',
             'Li': 'lithium',
             'Be': 'beryllium',
@@ -842,7 +768,7 @@ _predefinedDataFileDict['PYNEB_17_01']['C2']['rec'] = 'c_ii_rec_P91.func'
 _predefinedDataFileDict['PYNEB_17_01']['C3']['rec'] = 'c_iii_rec_P91.func'
 _predefinedDataFileDict['PYNEB_17_01']['C4']['rec'] = 'c_iv_rec_P91.func'
 _predefinedDataFileDict['PYNEB_17_01']['N1']['rec'] = 'n_i_rec_P91.func'
-_predefinedDataFileDict['PYNEB_17_01']['N2']['rec'] = 'n_ii_rec_P91.func'
+_predefinedDataFileDict['PYNEB_17_01']['N2']['rec'] = 'n_ii_rec_FSL11.func'
 _predefinedDataFileDict['PYNEB_17_01']['N2']['atom'] = 'n_ii_atom_FFT04.dat' 
 _predefinedDataFileDict['PYNEB_17_01']['N3']['rec'] = 'n_iii_rec_P91.func'
 _predefinedDataFileDict['PYNEB_17_01']['N4']['rec'] = 'n_iv_rec_P91.func'
@@ -861,6 +787,13 @@ _predefinedDataFileDict['PYNEB_17_01']['Ar3']['atom'] = 'ar_iii_atom_MB09.dat'
 _predefinedDataFileDict['PYNEB_17_01']['Ar3']['coll'] = 'ar_iii_coll_MB09.dat'
 _predefinedDataFileDict['PYNEB_17_01']['Ne5']['coll'] = 'ne_v_coll_DPNP13.dat'
 
+_predefinedDataFileDict['PYNEB_17_02'] = _predefinedDataFileDict['PYNEB_17_01'].copy()
+_predefinedDataFileDict['PYNEB_17_02']['Ne2']['rec'] = 'ne_ii_rec_KSDN98.func'
+
+_predefinedDataFileDict['PYNEB_18_01'] = _predefinedDataFileDict['PYNEB_17_02'].copy()
+_predefinedDataFileDict['PYNEB_18_01']['Te3'] = {'atom' : 'te_iii_atom_M18.dat',
+                                                 'coll': 'te_iii_coll_M18.dat'}
+
 # Next release, check with JGR:
 # ['Kr6'] = {'atom': 'kr_vi_atom_B05.dat', 'coll': 'kr_vi_coll_B16.dat'}
 # ['Se3']['coll'] = 'se_iii_coll_B16.dat'
@@ -906,19 +839,22 @@ See Morton (Ap. J. Suppl. 77, 119) for the formula used
 REVISION HISTORY
 Written W. Landsman November 1991
 Converted to IDL V5.0 W. Landsman September 1997
+Adding option to apply only between pn.config.vactoair_low_wl and pn.config.vactoair_high_wl
     """
-    
-    sigma2 = (1.e4/wave)**2. #Convert to wavenumber squared
+    wave_arr = np.asarray(wave)
+    sigma2 = (1.e4/wave_arr)**2. #Convert to wavenumber squared
     
     # Compute conversion factor
     
     fact = 1. + 6.4328e-5 + 2.94981e-2/(146.-sigma2) + 2.5540e-4/(41.-sigma2)
     
-    fact = fact*(wave >= 2000.) + 1.*(wave < 2000.)
+    mask_ok = (wave_arr >= pn.config.vactoair_low_wl) & (wave_arr <= pn.config.vactoair_high_wl)
+    fact = np.ones_like(wave_arr)
+    fact[mask_ok] = 1. + 6.4328e-5 + 2.94981e-2/(146.-sigma2[mask_ok]) + 2.5540e-4/(41.-sigma2[mask_ok])
     
-    wave = wave*fact #Convert Wavelength
+    wave_arr = wave_arr*fact #Convert Wavelength
     
-    return wave
+    return wave_arr
 
 
 
@@ -974,14 +910,17 @@ Written, D. Lindler 1982
 Documentation W. Landsman Feb. 1989
 Converted to IDL V5.0 W. Landsman September 1997
     """
+    wave_arr = np.asarray(wave)
 
-    wave2 = wave**2.
-    fact = 1. + 2.735182e-4 + 131.4182/wave2 + 2.76249e8/wave2**2.
-    fact = fact * ( wave >= 2000. ) + 1.*( wave < 2000. )
+    wave2 = wave_arr**2.
+    mask_ok = (wave_arr >= pn.config.vactoair_low_wl) & (wave_arr <= pn.config.vactoair_high_wl)
+    fact = np.ones_like(wave_arr)
+
+    fact[mask_ok] = 1. + 2.735182e-4 + 131.4182/wave2[mask_ok]  + 2.76249e8/wave2[mask_ok] **2.
     
     # Convert wavelengths
     
-    wave = wave/fact
+    wave_arr = wave_arr/fact
     
-    return wave
+    return wave_arr
 
